---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1992-10-23;421
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19921031&codiceRedaz=092G0463&dataVigenza=20251104
dataGU: 19921031
codiceRedaz: 092G0463
dataVigenza: 20251104
---

# Delega al Governo per la razionalizzazione e la revisione delle discipline in materia di sanita', di pubblico impiego, di previdenza e di finanza territoriale.

La Camera dei deputati ed il Senato della Repubblica hanno

approvato:

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## Art. 1. - (Sanita').

1. Ai fini della ottimale e razionale utilizzazione delle risorse destinate al Servizio sanitario nazionale, del perseguimento della migliore efficienza del medesimo a garanzia del cittadino, di equita' distributiva e del contenimento della spesa sanitaria, con riferimento all'articolo 32 della Costituzione, assicurando a tutti i cittadini il libero accesso alle cure e la gratuita' del servizio nei limiti e secondo i criteri previsti dalla normativa vigente in materia, il Governo della Repubblica, sentita la Conferenza permanente per i rapporti fra lo Stato, le regioni e le province autonome di Trento e di Bolzano, e' delegato ad emanare, entro novanta giorni dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi con l'osservanza dei seguenti principi e criteri direttivi:

- a) riordinare la disciplina dei ticket e dei prelievi contributivi, di cui all'articolo 31 della legge 28 febbraio 1986, n. 41, e succes- sive modificazioni ed integrazioni, sulla base del principio dell'uguaglianza di trattamento dei cittadini, anche attraverso l'unificazione dell'aliquota contributiva, da rendere proporzionale entro un livello massimo di reddito;
- b) rafforzare le misure contro le evasioni e le elusioni contributive e contro i comportamenti abusivi nella utilizzazione dei servizi, anche attraverso l'introduzione di limiti e modalita' personalizzate di fruizione delle esenzioni;
- c) completare il riordinamento del Servizio sanitario nazionale, attribuendo alle regioni e alle province autonome la competenza in materia di programmazione e organizzazione dell'assistenza sanitaria e riservando allo Stato, in questa materia, la programmazione sanitaria nazionale, la determinazione di livelli uniformi di assistenza sanitaria e delle relative quote capitarie di finanziamento, secondo misure tese al riequilibrio territoriale e strutturale, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano; ove tale intesa non intervenga entro trenta giorni il Governo provvede direttamente;
- d) definire i principi organizzativi delle unita' sanitarie locali come aziende infraregionali con personalita' giuridica, articolate secondo i principi della legge 8 giugno 1990, n. 142, stabilendo comunque che esse abbiano propri organi di gestione e prevedendo un direttore generale e un collegio dei revisori i cui membri, ad eccezione della rappresentanza del Ministero del tesoro, devono essere scelti tra i revisori contabili iscritti nell'apposito registro previsto dall'articolo 1 del decreto legislativo 27 gennaio 1992, n. 88. La definizione, nell'ambito della programmazione regionale, delle linee di indirizzo per l'impostazione programmatica delle attivita', l'esame del bilancio di previsione e del conto consuntivo con la remissione alla regione delle relative osservazioni, le verifiche generali sull'andamento delle attivita' per eventuali osservazioni utili nella predisposizione di linee di indirizzo per le ulteriori programmazioni sono attribuiti al sindaco o alla conferenza dei sindaci ovvero dei presidenti delle circoscrizioni di riferimento territoriale. Il direttore generale, che deve essere in possesso del diploma di laurea e di requisiti di comprovata professionalita' ed esperienza gestionale e organizzativa, e' nominato con scelta motivata dalla regione o dalla provincia autonoma tra gli iscritti all'elenco nazionale da istituire presso il Ministero della sanita' ed e' assunto con contratto di diritto privato a termine; e' coadiuvato da un direttore amministrativo e da un direttore sanitario in possesso dei medesimi requisiti soggettivi, assunti anch'essi con contratto di diritto privato a termine, ed e' assistito per le attivita' tecnico-sanitarie da un consiglio dei sanitari, composto da medici, in maggioranza, e da altri sanitari laureati, nonche' da una rappresentanza dei servizi infermieristici e dei tecnici sanitari; per la provincia autonoma di Bolzano e' istituito apposito elenco provinciale tenuto dalla stessa nel rispetto delle vigenti disposizioni in materia di bilinguismo e riserva proporzionale dei posti nel pubblico impiego; per la Valle d'Aosta e' istituito apposito elenco regionale tenuto dalla regione stessa nel rispetto delle norme in materia di bilinguismo;
- e) ridurre il numero delle unita' sanitarie locali, attraverso un aumento della loro estensione territoriale, tenendo conto delle specificita' delle aree montane;
- f) definire i principi relativi ai poteri di gestione spettanti al direttore generale;
- g) definire principi relativi ai livelli di assistenza sanitaria uniformi e obbligatori, tenuto conto della peculiarita' della categoria di assistiti di cui all'articolo 37 della legge 23 dicembre 1978, n. 833, espressi per le attivita' rivolte agli individui in termini di prestazioni, stabilendo comunque l'individuazione della soglia minima di riferimento, da garantire a tutti i cittadini, e il parametro capitario di finanziamento da assicurare alle regioni e alle province autonome per l'organizzazione di detta assistenza, in coerenza con le risorse stabilite dalla legge finanziaria;
- h) emanare, per rendere piene ed effettive le funzioni che vengono trasferite alle regioni e ella province autonome, entro il 30 giugno 1993, norme per la riforma del Ministero della sanita' cui rimangono funzioni di indirizzo e di coordinamento, nonche' tutte le funzioni attribuite dalle leggi dello Stato per la sanita' pubblica. Le stesse norme debbono prevedere altresi' il riordino dell'Istituto superiore di sanita', dell'Istituto superiore per la prevenzione e la sicurezza del lavoro (ISPESL) nonche' degli istituti di ricovero e cura a carattere scientifico e degli istituti zooprofilattici. Dette norme non devono comportare oneri a carico dello Stato;
- i) prevedere l'attribuzione, a decorrere dal 1 gennaio 1993, alle regioni e alle province autonome dei contributi per le prestazioni del Servizio sanitario nazionale localmente riscossi con riferimento al domicilio fiscale del contribuente e la contestuale riduzione del Fondo sanitario nazionale di parte corrente di cui all'articolo 51 della legge 23 dicembre 1978, n. 833, e successive modificazioni; imputare alle regioni e alle province autonome gli effetti finanziari per gli eventuali livelli di assistenza sanitaria superiori a quelli uniformi, per le dotazioni di presidi e di posti letto eccedenti gli standard previsti e per gli eventuali disavanzi di gestione da ripianare con totale esonero finanziario dello Stato; le regioni e le province autonome potranno far fronte ai predetti effetti finanziari con il proprio bilancio, graduando l'esonero dai ticket, salvo restando l'esonero totale dei farmaci salva-vita, variando in aumento entro il limite del 6 per cento l'aliquota dei contributi al lordo delle quote di contributo fiscalizzate per le prestazioni del Servizio sanitario nazionale (( ed entro il limite del 75 per cento )) l'aliquota dei tributi regionali vigenti; stabilire le modalita' ed i termini per la riscossione dei prelievi contributivi;
- l) introdurre norme volte, nell'arco di un triennio, alla revisione e al superamento dell'attuale regime delle convenzioni sulla base di criteri di integrazione con il servizio pubblico, di incentivazione al contenimento dei consumi sanitari, di valorizzazione del volontariato, di acquisizione delle prestazioni, da soggetti singoli o consortili, secondo principi di qualita' ed economicita', che consentano forme di assistenza differenziata per tipologie di prestazioni, al fine di assicurare ai cittadini migliore assistenza e liberta' di scelta;
- m) prevedere che con decreto interministeriale, da emanarsi d'intesa con la Conferenza permanente per i rapporti fra lo Stato, le regioni e le province autonome di Trento e di Bolzano, siano individuate quote di risorse disponibili per le forme di assistenza differenziata di cui alla lettera l);
- n) stabilire i criteri per le individuazioni degli ospedali di rilievo nazionale e di alta specializzazione, compresi i policlinici universitari, e degli ospedali che in ogni regione saranno destinati a centro di riferimento della rete dei servizi di emergenza, ai quali attribuire personalita' giuridica e autonomia di bilancio, finanziaria, gestionale e tecnica e prevedere, anche per gli altri presidi delle unita' sanitarie locali, che la relativa gestione sia informata al principio dell'autonomia economico-finanziaria e dei preventivi e consuntivi per centri di costo, basato sulle prestazioni effettuate, con appropriate forme di incentivazione per il potenziamento dei servizi ospedalieri diurni e la deospedalizzazione dei lungodegenti;
- o) prevedere nuove modalita' di rapporto tra Servizio sanitario nazionale ed universita' sulla base di principi che, nel rispetto delle attribuzioni proprie dell'universita' regolino l'apporto all'attivita' assistenziale delle facolta' di medicina, secondo le modalita' stabilite dalla programmazione regionale in analogia con quanto previsto, anche in termini di finanziamento, per le strutture ospedaliere; nell'ambito di tali modalita' va peraltro regolamentato il rapporto tra Servizio sanitario nazionale ed universita' per la formazione in ambito ospedaliero del personale sanitario e per le specializzazioni post-laurea;
- p) prevedere il trasferimento alle aziende infraregionali e agli ospedali dotati di personalita' giuridica e di autonomia organizzativa del patrimonio mobiliare e immobiliare gia' di proprieta' dei disciolti enti ospedalieri e mutualistici che alla data di entrata in vigore della presente legge fa parte del patrimonio dei comuni;
- q) prevedere che il rapporto di lavoro del personale dipendente sia disciplinato in base alle disposizioni dell'articolo 2 della presente legge, individuando in particolare i livelli dirigenziali secondo criteri di efficienza, di non incremento delle dotazioni organiche di ciascuna delle attuali posizioni funzionali e di rigorosa selezione negli accessi ai nuovi livelli dirigenziali cui si perverra' soltanto per pubblico concorso, configurando il livello dirigenziale apicale, per quanto riguarda il personale medico e per le altre professionalita' sanitarie, quale incarico da conferire a dipendenti forniti di nuova, specifica idoneita' nazionale all'esercizio delle funzioni di direzione e rinnovabile, definendo le modalita' di accesso, le attribuzioni e le responsabilita' del personale dirigenziale, ivi incluse quelle relative al personale medico, riguardo agli interventi preventivi, clinici, diagnostici e terapeutici, e la regolamentazione delle attivita' di tirocinio e formazione di tutto il personale;
- r) definire i principi per garantire i diritti dei cittadini nei confronti del servizio sanitario anche attraverso gli organismi di volontariato e di tutela dei diritti, favorendo la presenza e l'attivita' degli stessi all'interno delle strutture e prevedendo modalita' di partecipazione e di verifica nella programmazione dell'assistenza sanitaria e nella organizzazione dei servizi. Restano salve le competenze ed attribuzioni delle regioni a statuto speciale e delle province autonome di Trento e di Bolzano;
- s) definire i principi ed i criteri per la riorganizzazione, da parte delle regioni e province autonome, su base dipartimentale, dei presidi multizonali di prevenzione, di cui all'articolo 22 della legge 23 dicembre 1978, n. 833, cui competono le funzioni di coordinamento tecnico dei servizi delle unita' sanitarie locali, nonche' di consulenza e supporto in materia di prevenzione a comuni, province o altre amministrazioni pubbliche ed al Ministero dell'ambiente; prevedere che i servizi delle unita' sanitarie locali, cui competono le funzioni di cui agli articoli 16, 20, 21 e 22 della legge 23 dicembre 1978, n. 833, siano organizzati nel dipartimento di prevenzione, articolato almeno nei servizi di prevenzione ambientale, igiene degli alimenti, prevenzione e sicurezza degli ambienti di lavoro, igiene e sanita' pubblica, veterinaria in riferimento alla sanita' animale, all'igiene e commercializzazione degli alimenti di origine animale e all'igiene degli allevamenti e delle produzioni zootecniche;
- t) destinare una quota del Fondo sanitario nazionale ad attivita' di ricerca di biomedica finalizzata, alle attivita' di ricerca di istituti di rilievo nazionale, riconosciuti come tali dalla normativa vigente in materia, dell'Istituto superiore di sanita' e dell'Istituto superiore per la prevenzione e la sicurezza del lavoro (ISPESL), nonche' ad iniziative centrali previste da leggi nazionali riguardanti programmi speciali di interesse e rilievo interregionale o nazionale da trasferire allo stato di previsione del Ministero della sanita';
- u) allo scopo di garantire la puntuale attuazione delle misure attribuite alla competenza delle regioni e delle province autonome, prevedere che in caso di inadempienza da parte delle medesime di adempimenti previsti dai decreti legislativi di cui al presente articolo, il Consiglio dei ministri, su proposta del Ministro della sanita', disponga, previa diffida, il compimento degli atti relativi in sostituzione delle predette amministrazioni regionali o provinciali;
- v) prevedere l'adozione, da parte delle regioni e delle province autonome, entro il 1 gennaio 1993, del sistema di lettura ottica delle prescrizioni mediche, attivando, secondo le modalita' previste dall'articolo 4, comma 4, della legge 30 dicembre 1991, n. 412, le apposite commissioni professionali di verifica. Qualora il termine per l'attivazione del sistema non fosse rispettato, il Ministro della sanita', sentito il parere della Conferenza permanente per i rapporti fra lo Stato, le regioni e le province autonome di Trento e di Bolzano, attiva i poteri sostitutivi consentiti dalla legge; ove tale parere non sia espresso entro trenta giorni il Ministro provvede direttamente;
- z) restano salve le competenze e le attribuzioni delle regioni a statuto speciale e delle province autonome di Trento e di Bolzano.

2. Sono prorogate fino al 31 dicembre 1993 le norme dell'articolo 4, comma 4, della legge 30 dicembre 1991, n. 412, concernenti l'ammissione nel prontuario terapeutico nazionale di nuove specialita' che rappresentino modifiche di confezione o di composizione o di forma o di dosaggio di specialita' gia' presenti nel prontuario e che comportino un aumento del costo del ciclo terapeutico.

3. Entro sessanta giorni dalla data di entrata in vigore della presente legge il Governo trasmette alla Camera dei deputati e al Senato della Repubblica gli schemi dei decreti legislativi di cui al comma 1 al fine dell'espressione del parere da parte delle Commissioni permamenti competenti per la materia di cui al presente articolo. Le Commissioni si esprimono entro quindici giorni dalla data di trasmissione.

4. Disposizioni correttive, nell'ambito dei decreti di cui al comma 1, nel rispetto dei principi e criteri direttivi determinati dal medesimo comma 1 e previo parere delle Commissioni di cui al comma 3, potranno essere emanate, con uno o piu' decreti legislativi, fino al 31 dicembre 1993.

## Art. 2. - (Pubblico impiego).

1. Il Governo della Repubblica e' delegato a emanare entro novanta giorni dalla data di entrata in vigore della presente legge uno o piu' decreti legislativi, diretti al contenimento, alla razionalizzazione e al controllo della spesa per il settore del pubblico impiego, al miglioramento dell'efficienza e della produttivita', nonche' alla sua riorganizzazione; a tal fine e' autorizzato a:

- a) prevedere, con uno o piu' decreti, salvi i limiti collegati al perseguimento degli interessi generali cui l'organizzazione e l'azione delle pubbliche amministrazioni sono indirizzate, che i rapporti di lavoro e di impiego dei dipendenti delle amministrazioni dello Stato e degli altri enti di cui agli articoli 1, primo comma, e 26, primo comma, della legge 29 marzo 1983, n. 93, siano ricondotti sotto la disciplina del diritto civile e siano regolati mediante contratti individuali e collettivi; prevedere una disciplina transitoria idonea ad assicurare la graduale sostituzione del regime attualmente in vigore nel settore pubblico con quello stabilito in base al presente articolo; prevedere nuove forme di partecipazione delle rappresentanze del personale ai fini dell'organizzazione del lavoro nelle amministrazioni;
- b) prevedere criteri di rappresentativita' ai fini dei diritti sindacali e della contrattazione compatibili con le norme costituzionali; prevedere strumenti per la rappresentanza negoziale della parte pubblica, autonoma ed obbligatoria, mediante un apposito organismo tecnico, dotato di personalita' giuridica, sottoposto alla vigilanza della Presidenza del Consiglio dei ministri ed operante in conformita' alle direttive impartite dal presidente del Consiglio dei ministri; stabilire che l'ipotesi di contratto collettivo, corredata dai necessari documenti indicativi degli oneri finanziari, sia trasmessa dall'organismo tecnico, ai fini dell'autorizzazione alla sottoscrizione, al Governo che dovra' pronunciarsi in senso positivo o negativo entro un termine non superiore a quindici giorni, decorso il quale l'autorizzazione si intende rilasciata; prevedere che la legittimita' e la compatibilita' economica dell'autorizzazione governativa siano sottoposte al controllo della Corte dei conti, che dovra' pronunciarsi entro un termine certo, decorso il quale il controllo si intende effettuato senza rilievi;
- c) prevedere l'affidamento delle controversie di lavoro riguardanti i pubblici dipendenti, cui si applica la disciplina di cui al presente articolo, escluse le controversie riguardanti il personale di cui alla lettera e) e le materie di cui ai numeri da 1) a 7) della presente lettera, alla giurisdizione del giudice ordinario secondo le disposizioni che regolano il processo del lavoro, a partire dal terzo anno successivo alla emanazione del decreto legislativo e comunque non prima del compimento della fase transitoria di cui alla lettera a); la procedibilita' del ricorso giurisdizionale resta subordinata all'esperimento di un tentativo di conciliazione, che, in caso di esito positivo, si definisce mediante verbale costituente titolo esecutivo. Sono regolate con legge, ovvero, sulla base della legge o nell'ambito dei principi dalla stessa posti, con atti normativi o amministrativi, le seguenti materie: 1) le responsabilita' giuridiche attinenti ai singoli operatori nell'espletamento di procedure amministrative; 2) gli organi, gli uffici, i modi di conferimento della titolarita' dei medesimi; 3) i principi fondamentali di organizzazione degli uffici; 4) i procedimenti di selezione per l'accesso al lavoro e di avviamento al lavoro; 5) i ruoli e le dotazioni organiche nonche' la loro consistenza complessiva. Le dotazioni complessive di ciascuna qualifica sono def- inite previa informazione alle organizzazioni sindacali interessate maggiormente rappresentative sul piano nazionale; 6) la garanzia della liberta' di insegnamento e l'autonomia professionale nello svolgimento dell'attivita' didattica, scientifica e di ricerca; 7) la disciplina della responsabilita' e delle incompatibilita' tra l'impiego pubblico ed altre attivita' e i casi di divieto di cumulo di impieghi e incarichi pubblici;
- d) prevedere che le pubbliche amministrazioni e gli enti pubblici di cui alla lettera a) garantiscano ai propri dipendenti parita' di trattamenti contrattuali e comunque trattamenti non inferiori a quelli prescritti dai contratti collettivi;
- e) mantenere la normativa vigente, prevista dai rispettivi ordinamenti, per quanto attiene ai magistrati ordinari e amministrativi, agli avvocati e procuratori dello Stato, al personale militare e delle forze di polizia, (( . . . )) al personale delle carriere diplomatica e prefettizia;
- f) prevedere la definizione di criteri di unicita' di ruolo dirigenziale, fatti salvi i distinti ruoli delle carriere diplomatica e prefettizia e le relative modalita' di accesso; prevedere criteri generali per la nomina dei dirigenti di piu' elevato livello, con la garanzia di specifiche obiettive capacita' professionali; prevedere una disciplina uniforme per i procedimenti di accesso alle qualifiche dirigenziali di primo livello anche mediante norme di riordino della Scuola superiore della pubblica amministrazione, anche in relazione alla funzione di accesso, senza oneri aggiuntivi a carico del bilancio dello Stato, prevedendo figure di vertice con distinte responsabilita' didattico-scientifiche e gestionali-organizzative;
- g) prevedere: 1) la separazione tra i compiti di direzione politica e quelli di direzione amministrativa; l'affidamento ai dirigenti - nell'ambito delle scelte di programma degli obiettivi e delle direttive fissate dal titolare dell'organo - di autonomi poteri di direzione, di vigilanza e di controllo, in particolare la gestione di risorse finanziarie attraverso l'adozione di idonee tecniche di bilancio, la gestione delle risorse umane e la gestione di risorse strumentali; cio' al fine di assicurare economicita', speditezza e rispondenza al pubblico interesse dell'attivita' degli uffici dipendenti; 2) la verifica dei risultati mediante appositi nuclei di valutazione composti da dirigenti generali e da esperti, ovvero attraverso convenzioni con organismi pubblici o privati particolarmente qualificati nel controllo di gestione; 3) la mobilita', anche temporanea, dei dirigenti, nonche' la rimozione dalle funzioni e il collocamento a disposizione in caso di mancato conseguimento degli obiettivi prestabiliti della gestione; 4) i tempi e i modi per l'individuazione, in ogni pubblica amministrazione, degli organi e degli uffici dirigenziali in relazione alla rilevanza e complessita' delle funzioni e della quantita' delle risorse umane, finanziarie, strumentali assegnate; tale individuazione dovra' comportare anche eventuali accorpamenti degli uffici esistenti; dovranno essere previsti i criteri per l'impiego e la graduale riduzione del numero dei dirigenti in servizio che risultino in eccesso rispetto agli uffici individuati ai sensi della presente norma; 5) una apposita, separata area di contrattazione per il personale dirigenziale non compreso nella lettera e), cui partecipano le confederazioni sindacali maggiormente rappresentative sul piano nazionale e le organizzazioni sindacali del personale interessato maggiormente rappresentative sul piano nazionale, assicurando un adeguato riconoscimento delle specifiche tipologie professionali; la definizione delle qualifiche dirigenziali e delle relative attribuzioni; l'istituzione di un'area di contrattazione per la dirigenza medica, stabilendo che la relativa delegazione sindacale sia composta da rappresentanti delle organizzazioni sindacali del personale medico maggiormente rappresentative sul piano nazionale;
- h) prevedere procedure di contenimento e controllo della spesa globale per i dipendenti pubblici, entro limiti massimi globali, per ciascun comparto e per ciascuna amministrazione o ente; prevedere, nel bilancio dello Stato e nei bilanci delle altre amministrazioni ed enti, l'evidenziazione della spesa complessiva per il personale, a preventivo e a consuntivo; prevedere la revisione dei controlli amministrativi dello Stato sulle regioni, concentrandoli sugli atti fondamentali della gestione ed assicurando l'audizione dei rappresentanti dell'ente controllato, adeguando altresi' la composizione degli organi di controllo anche al fine di garantire l'uniformita' dei criteri di esercizio del controllo stesso;
- i) (( prevedere che la struttura della contrattazione, le aree di contrattazione e il rapporto tra i diversi livelli siano definiti in coerenza con quelli del settore privato ));
- l) definire procedure e sistemi di controllo sul conseguimento degli obiettivi stabiliti per le azioni amminstrative, nonche' sul contenimento dei costi contrattuali entro i limiti predeterminati dal Governo e dalla normativa di bilancio, prevedendo negli accordi contrattuali dei pubblici dipendenti la possibilita' di prorogare l'efficacia temporale del contratto, ovvero di sospenderne l'esecuzione parziale o totale in caso di accertata esorbitanza dai limiti di spesa; a tali fini, prevedere che il Nucleo di valutazione della spesa relativa al pubblico impiego istituito presso il Consiglio nazionale dell'economia e del lavoro dall'articolo 10 della legge 30 dicembre 1991, n. 412, operi, su richiesta del Presidente del Consiglio dei ministri o delle organizzazioni sindacali, nell'ambito dell'attuale dotazione finanziaria dell'ente, con compiti sostitutivi di quelli affidatigli dal citato articolo 10 della legge 30 dicembre 1991, n. 412, di controllo e certificazione dei costi del lavoro pubblico sulla base delle rilevazioni effettuate dalla Ragioneria generale dello Stato, dal Dipartimento della funzione pubblica e dall'Istituto nazionale di statistica; per il piu' efficace perseguimento di tali obiettivi, realizzare l'integrazione funzionale del Dipartimento della funzione pubblica con la Ragioneria generale dello Stato;
- m) prevedere, nelle ipotesi in cui per effetto di decisioni giurisdizionali l'entita' globale della spesa per il pubblico impiego ecceda i limiti prestabiliti dal Governo, che il Ministro del bilancio e della programmazione economica ed il Ministro del tesoro presentino, in merito, entro trenta giorni dalla pubblicazione delle sentenze esecutive, una relazione al Parlamento impegnando Governo e Parlamento a definire con procedura d'urgenza una nuova disciplina legislativa idonea a ripristinare i limiti della spesa globale;
- n) prevedere che, con riferimento al settore pubblico, in deroga all'articolo 2103 del codice civile, l'esercizio temporaneo di mansioni superiori non attribuisce il diritto all'assegnazione definitiva delle stesse, che sia consentita la temporanea assegnazione con provvedimento motivato del dirigente alle mansioni superiori per un periodo non eccedente tre mesi o per sostituzione del lavoratore assente con diritto alla conservazione del posto esclusivamente con il riconoscimento del diritto al trattamento corrispondente all'attivita' svolta e che comunque non costituisce assegnazione alle mansioni superiori l'attribuzione di alcuni soltanto dei compiti propri delle mansioni stesse, definendo altresi' criteri, procedure e modalita' di detta assegnazione;
- o) procedere alla abrogazione delle disposizioni che prevedono automatismi che influenzano il trattamento economico fondamentale ed accessorio, e di quelle che prevedono trattamenti economici accessori, settoriali, comunque denominati, a favore di pubblici dipendenti sostituendole contemporaneamente con corrispondenti disposizioni di accordi contrattuali anche al fine di collegare direttamente tali trattamenti alla produttivita' individuale e a quella collettiva ancorche' non generalizzata ma correlata all'apporto partecipativo, raggiunte nel periodo, per la determinazione delle quali devono essere introdotti sistemi di valutazione e misurazione, ovvero allo svolgimento effettivo di attivita' particolarmente disagiate ovvero obiettivamente pericolose per l'incolumita' personale o dannose per la salute; prevedere che siano comunque fatti salvi i trattamenti economici fondamentali ed accessori in godimento aventi natura retributiva ordinaria o corrisposti con carattere di generalita' per ciascuna amministrazione o ente; prevedere il principio della responsabilita' personale dei dirigenti in caso di attribuzione impropria dei trattamenti economici accessori;
- p) prevedere che qualunque tipo di incarico a dipendenti della pubblica amministrazione possa essere conferito in casi rigorosamente predeterminati; in ogni caso, prevedere che l'amministrazione, ente, societa' o persona fisica che hanno conferito al personale dipendente da una pubblica amministrazione incarichi previsti dall'articolo 24 della legge 30 dicembre 1991, n. 412, entro sei mesi dell'emanazione dei decreti legislativi di cui al presente articolo, siano tenuti a comunicare alle amministrazioni di appartenenza del personale medesimo gli emolumenti corrisposti in relazione ai predetti incarichi, allo scopo di favorire la completa attuazione dell'anagrafe delle prestazioni prevista dallo stesso articolo 24;
- q) (( LETTERA ABROGATA DALLA L. 15 marzo 1997, N. 59 )).
- r) prevedere, al fine di assicurare la migliore distribuzione del personale nelle sedi di servizio sul territorio nazionale, che le amministrazioni e gli enti pubblici non possano procedere a nuove assunzioni, ivi comprese quelle riguardanti le categorie protette, in caso di mancata rideterminazione delle piante organiche secondo il disposto dell'articolo 6 della legge 30 dicembre 1991, n. 412, ed in caso di accertata possibilita' di copertura dei posti vacanti mediante mobilita' volontaria, ancorche' realizzabile a seguito della copertura del fabbisogno di personale nella sede di provenienza; prevedere norme dirette ad impedire la violazione e l'elusione degli obblighi temporanei di permanenza dei dipendenti pubblici in determi- nate sedi, stabilendo in sette anni il relativo periodo di effettiva permanenza nella sede di prima destinazione, escludendo anche la possibilita' di disporre in tali periodi comandi o distacchi presso sedi con dotazioni organiche complete; prevedere che i trasferimenti mediante mobilita' volontaria, compresi quelli di cui al comma 2 dell'articolo 4 della legge 29 dicembre 1988, n. 554, siano adottati con decreto del Presidente del Consiglio dei ministri e che il personale eccedente, che non accetti la mobilita' volontaria, sia sottoposto a mobilita' d'ufficio e, qualora non ottemperi, sia collocato in disponibilita' ai sensi dell'articolo 72 del testo unico delle disposizioni concernenti lo statuto degli impiegati civili dello Stato approvato con decreto del Presidente della Repubblica 10 gennaio 1957, n. 3;
- s) prevedere che, fatte salve le disposizioni di leggi speciali, la disciplina del trasferimento di azienda di cui all'articolo 2112 del codice civile si applica anche nel caso di transito dei dipendenti degli enti pubblici e delle aziende municipalizzate o consortili a societa' private per effetto di norme di legge, di regolamento o convenzione, che attribuiscano alle stesse societa' le funzioni esercitate dai citati enti pubblici ed aziende;
- t) prevedere una organica regolamentazione delle modalita' di accesso all'impiego presso le pubbliche amministrazioni, espletando, a cura della Presidenza del Consiglio dei ministri, concorsi unici per profilo professionale (( da espletarsi a livello regionale )) abilitanti all'impiego presso le pubbliche amministrazioni, ad eccezione delle regioni, degli enti locali e loro consorzi, previa individuazione dei profili professionali, delle procedure e tempi di svolgimento dei concorsi, nonche' delle modalita' di accesso alle graduatorie di idonei da parte delle amministrazioni pubbliche, prevedendo altresi' la possibilita', in determinati casi, di provvedere attraverso concorsi per soli titoli o di selezionare i candidati mediante svolgimento di prove psico-attitudinali avvalendosi di sistemi automatizzati; prevedere altresi' il decentramento delle sedi di svolgimento dei concorsi;
- u) prevedere per le categorie protette di cui al titolo I della legge 2 aprile 1968, n. 482, l'assunzione, da parte dello Stato, delle aziende e degli enti pubblici, per chiamata numerica degli iscritti nelle liste di collocamento sulla base delle graduatorie stabilite dagli uffici provinciali del lavoro e della massima occupazione;
- v) al fine di assicurare una migliore efficienza degli uffici e delle strutture delle amministrazioni pubbliche in relazione alle rispettive inderogabili esigenze funzionali, prevedere che il personale appartenente alle qualifiche funzionali possa essere utilizzato, occasionalmente e con criteri di flessibilita', per lo svolgimento di mansioni relative a profili professionali di qualifica funzionale immediatamente inferiore;
- z) prevedere, con riferimento al titolo di studio, l'utilizzazione, anche d'ufficio, del personale docente soprannumerario delle scuole di ogni ordine e grado di posti e classi di concorso diversi da quelli di titolarita', anche per ordini e gradi di scuola diversi; il passaggio di ruolo del predetto personale docente soprannumerario e' consentito purche' in possesso di idonea abilitazione e specializzazione, ove richiesta, secondo la normativa vigente; prevedere il passaggio del personale docente in soprannumero e del personale amministrativo, tecnico ed ausiliario utilizzato presso gli uffici scolastici regionali e provinciali, a domanda, nelle qualifiche funzionali, nei profili professionali e nelle sedi che presentino disponibilita' di posti, nei limiti delle dotazioni organiche dei ruoli dell'amministrazione centrale e dell'amministrazione scolastica periferica del Ministero della pubblica istruzione previste cumulativamente dalle tabelle A e B allegate al decreto del Presidente del Consiglio dei ministri 27 luglio 1987, pubblicato nel Supplemento ordinario alla Gazzetta Ufficiale n. 33 dell'8 febbraio 1991, e successive modificazioni;
- aa) prevedere per il personale docente di ruolo l'istituzione di corsi di riconversione professionale, con verifica finale, aventi valore abilitante, l'accesso ai quali avvenga sulla base dei titoli di studio posseduti al fine di rendere possibile una maggiore mobilita' professionale all'interno del comparto scuola in relazione ai fenomeni di diminuzione della popolazione scolastica e ai cambiamenti degli ordinamenti e dei programmi di insegnamento; prevedere nell'ambito delle trattative contrattuali l'equiparazione della mobilita' professionale (passaggi di cattedra e di ruolo) a quella territoriale ed il superamento dell'attuale ripartizione tra i posti riservati alla mobilita' e quelli riservati alle immissioni in ruolo nel senso di rendere disponibili per le immissioni in ruolo solo i posti che residuano dopo le operazioni di mobilita' in ciascun anno scolastico;
- bb) prevedere norme dirette alla riduzione graduale delle dotazioni organiche aggiuntive per le scuole materne e per gli istituti e scuole d'istruzione secondaria ed artistica, fino al raggiungimento del 3 per cento della consistenza organica, a modifica di quanto previsto dall'articolo 13, primo comma, della legge 20 maggio 1982, n. 270, e successive modificazioni e integrazioni; sopprimere, con decorrenza dall'anno scolastico 1993-94, i commi decimo e undicesimo dell'articolo 14 della citata legge 20 maggio 1982, n. 270, e prevedere norme dirette alla progressiva abolizione delle attuali disposizioni che autorizzano l'impiego del personale della scuola in funzioni diverse da quelle di istituto; conseguentemente dovra' essere prevista una nuova regolamentazione di tutte le forme di utilizzazione del personale della scuola per garantirne l'impiego, anche attraverso forme di reclutamento per concorso, in attivita' di particolare utilita' strettamente attinenti al settore educativo e per fini di istituto anche culturali previsti da leggi in vigore. Tale nuova regolamentazione potra' consentire una utilizzazione complessiva di personale non superiore alle mille unita';
- cc) prevedere che le dotazioni dell'organico aggiuntivo siano destinate prevalentemente alla copertura delle supplenze annuali. Cio' nell'ambito delle quote attualmente stabilite per le diverse attivita' di cui all'articolo 14 della legge 20 maggio 1982, n. 270, e successive modificazioni;
- dd) procedere alla revisione delle norme concernenti il conferimento delle supplenze annuali e temporanee per il personale docente, amministrativo, tecnico ed ausiliario prevedendo la possibilita' di fare ricorso alle supplenze annuali solo per la copertura dei posti effettivamente vacanti e disponibili ed ai quali non sia comunque assegnato personale ad altro titolo per l'intero anno scolastico, stabilendo la limitazione delle supplenze temporanee al solo periodo di effettiva permanenza delle esigenze di servizio; procedere alla revisione della disciplina che regola l'utilizzazione del personale docente che riprende servizio dopo l'aspettativa per infermita' o per motivi di famiglia; nelle sole classi terminali dei cicli di studio ove il docente riprenda servizio dopo il 30 aprile ed a seguito di un periodo di assenza non inferiore a novanta giorni, viene confermato il supplente a garanzia della continuita' didattica e i docenti di ruolo che non riprendano servizio nella propria classe sono impiegati per supplenze o per lo svolgimento di altri compiti;
- ee) procedere alla revisione, nell'ambito dell'attuale disciplina del reclutamento del personale docente di ruolo, dei criteri di costituzione e funzionamento delle commissioni giudicatrici, al fine di realizzare obiettivi di accelerazione, efficienza e contenimento complessivo della spesa nello svolgimento delle procedure di concorso mediante un piu' razionale accorpamento delle classi di concorso ed il maggior decentramento possibile delle sedi di esame, nonche' un piu' frequente ricorso alla scelta dei componenti delle commissioni fra il personale docente e direttivo in quiescenza, anche ai sensi del decreto del Presidente del Consiglio dei ministri 10 giugno 1986, pubblicato nella Gazzetta Ufficiale n. 190 del 18 agosto 1986, e suc- cessive modificazioni, ed assicurando un adeguato compenso ai componenti delle commissioni stesse nei casi in cui essi non optino per l'esonero dal servizio di insegnamento. La corresponsione dei citati compensi deve comunque comportare una adeguata economia di spesa rispetto agli oneri eventualmente da sostenere per la sostituzione del personale esonerato dal servizio di insegnamento;
- ff) procedere alla revisione, nell'ambito dell'attuale disciplina del reclutamento del personale docente di ruolo, delle relative procedure di concorso, al fine di subordinarne l'indizione alla previsione di effettiva disponibilita' di cattedre e di posti e, per quanto riguarda le accademie ed i conservatori, di subordinarne lo svolgimento ad una previa selezione per soli titoli;
- gg) prevedere l'individuazione di parametri di efficacia della spesa per la pubblica istruzione in rapporto ai risultati del sistema scolastico con particolare riguardo alla effettiva fruizione del diritto allo studio ed in rapporto anche alla mortalita' scolastica, agli abbandoni e al non adempimento dell'obbligo, individuando strumenti efficaci per il loro superamento;
- hh) prevedere criteri e progetti per assicurare l'attuazione della legge 10 aprile 1991, n. 125, in tutti i settori del pubblico impiego;
- ii) prevedere l'adeguamento degli uffici e della loro organizzazione al fine di garantire l'effettivo esercizio dei diritti dei cittadini in materia di procedimento amministrativo e di diritto di accesso ai documenti amministrativi, ai sensi della legge 7 agosto 1990, 241;
- ll) i dipendenti delle pubbliche amministrazioni eletti al Parlamento nazionale, al Parlamento europeo e nei consigli regionali sono collocati in aspettativa senza assegni per la durata del mandato. Tale periodo e' utile ai fini dell'anzianita' di servizio e del trattamento di quiescenza e di previdenza;
- mm) al fine del completamento del processo di informatizzazione delle amministrazioni pubbliche e della piu' razionale utilizzazione dei sistemi informativi automatizzati, procedere alla revisione della normativa in materia di acquisizione dei mezzi necessari; prevedendo altresi' la definizione dei relativi standard qualitativi e dei controlli di efficenza e di efficacia; procedere alla revisione delle relative competenze e attribuire ad un apposito organismo funzioni di coordinamento delle iniziative e di pianificazione degli investimenti in materia di automazione, anche al fine di garantire l'interconnessione dei sistemi informatici pubblici.

2. Le disposizioni del presente articolo e dei decreti legislativi in esso previsti costituiscono principi fondamentali ai sensi dell'articolo 117 della Costituzione. I principi desumibili dalle disposizioni del presente articolo costituiscono altresi' per le regioni a statuto speciale e per le province autonome di Trento e di Bolzano norme fondamentali di riforma economico-sociale della Repubblica.

3. Restano salve per la Valle d'Aosta le competenze statutarie in materia, le norme di attuazione e la disciplina sul bilinguismo. Resta comunque salva, per la provincia autonoma di Bolzano, la disciplina vigente sul bilinguismo e la riserva proporzionale di posti nel pubblico impiego.

4. Entro sessanta giorni dalla data di entrata in vigore della presente legge il Governo trasmette alla Camera dei deputati e al Senato della Repubblica gli schemi dei decreti legislativi di cui al comma 1 al fine dell'espressione del parere da parte delle Commissioni permanenti competenti per la materia di cui al presente articolo. Le Commissioni si esprimono entro quindici giorni dalla data di trasmissione.

5. Disposizioni correttive, nell'ambito dei decreti di cui al comma 1, nel rispetto dei principi e criteri direttivi determinati dal medesimo comma 1 e previo parere delle Commissioni di cui al comma 4, potranno essere emanate, con uno o piu' decreti legislativi, fino al 31 dicembre 1993.

## Art. 3. - Previdenza

1. Il Governo della Repubblica e' delegato ad emanare, entro novanta giorni dalla data di entrata in vigore della presente legge, salvo quanto previsto al comma 2 del presente articolo, uno o piu' decreti legislativi per il riordino del sistema previdenziale dei lavoratori dipendenti privati e pubblici, salvaguardando i diritti quesiti, con lo scopo di stabilizzare al livello attuale il rapporto tra spesa previdenziale e prodotto interno lordo e di garantire, in base alle disposizioni di cui all'articolo 38 della Costituzione e ferma restando la pluralita' degli organismi assicurativi, trattamenti pensionistici obbligatori omogenei, nonche' di favorire la costituzione, su base volontaria, collettiva o individuale, di forme di previdenza per l'erogazione di trattamenti pensionistici complementari, con l'osservanza dei seguenti principi e criteri direttivi:

- a) elevazione graduale del limite di eta' a sessanta anni per le donne e a sessantacinque anni per gli uomini in ragione di un anno ogni due anni dal 1994;
- b) conferma dei limiti di eta' eventualmente piu' elevati gia' in vigore per le forme di previdenza sostitutive od esclusive del regime generale obbligatorio, per uomini e donne, facolta' di permanere in servizio oltre i limiti di eta' per un periodo massimo di un biennio per i dipendenti civili dello stato e degli enti pubblici non economici con decorrenza dalla data di entrata in vigore della presente legge; facolta' di deroga per gli inabili in misura non inferiore all'80 per cento, nonche', con conferma dei vigenti limiti di eta', per i lavoratori non vedenti, per il personale militare, per il personale viaggiante del settore autoferrotranviario, per il personale di volo e per i lavoratori dello spettacolo, ivi compresi i calciatori, gli allenatori di calcio e gli sportivi professionisti;
- c) elevazione fino al compimento del sessantacinquesimo anno di eta' del limite previsto per l'applicazione delle disposizioni contenute nell'articolo 6 della legge 29 dicembre 1990, n. 407, per la prosecuzione facoltativa del rapporto di lavoro;
- d) elevazione della percentuale di commisurazione della pensione per ogni anno di anzianita' contributiva acquisita dal lavoratore per effetto dell'esercizio dell'opzione di continuare a prestare la sua opera per periodi successivi al compimento dell'eta' pensionabile fino al compimento del sessantacinquesimo anno di eta' in misura idonea ad incentivare il differimento del trattamento pensionistico e compatibile con l'obiettivo di contenimento della spesa previdenziale;
- e) subordinazione del conseguimento del diritto alla pensione di vecchiaia alla cessazione del rapporto di lavoro;
- f) anticipazione dei limiti di eta' pensionabile di due mesi per ogni anno di occupazione in attivita' particolarmente usuranti, fatto salvo il disposto dell'articolo 2 della legge 28 marzo 1991, n. 120, fino ad un massimo di sessanta mesi, con copertura del maggior onere a carico dei settori interessati, senza aggravi a carico del bilancio dello Stato. A tal fine saranno individuate, sentite le organizzazioni sindacali dei lavoratori dipendenti ed autonomi e sulla base della relazione di una commissione tecnico -scientifica, le categorie e figure professionali dei lavoratori addetti a tali attivita', nonche' i relativi apporti della contribuzione integrativa;
- g) graduale elevazione da quindici anni a venti anni del requisito di assicurazione e contribuzione per il diritto a pensione dei lavoratori dipendenti ed autonomi, in ragione di un anno ogni due anni, con esclusione degli assicurati che al 31 dicembre 1992 abbiano conseguito il requisito minimo in base alla normativa vigente e dei soggetti che per un periodo non inferiore a dieci anni solari siano assicurati in relazione a rapporti di lavoro a tempo determinato inferiore a cinquantadue settimane per anno solare, purche' risultino assicurati da almeno venticinque anni, nonche' dei soggetti che siano stati ammessi ad effettuare versamenti volontari anteriormente al 31 dicembre 1992;
- h) graduale elevazione del periodo di riferimento per la determinazione della retribuzione annua pensionabile da duecentosessanta a cinquecentoventi settimane di contribuzione antecedenti la decorrenza della pensione, in ragione di un anno ogni due anni, con rivalutazione delle retribuzioni, in relazione alle variazioni del costo della vita con aumento di un punto percentuale, con graduale estensione di tale meccanismo nei confronti degli iscritti alle forme sostitutive ed esclusive del regime generale obbligatorio, in ragione di un anno ogni due anni; per coloro che possono far valere una anzianita' contributiva inferiore a quindici anni nell'assicurazione generale obbligatoria, nelle forme sostitutive ed esclusive del regime generale e nelle gestioni speciali dei lavoratori autonomi, il periodo di riferimento per la individuazione della retribuzione pensionabile e' determinato aggiungendo al periodo stabilito dalla normativa vigente nei singoli ordinamenti quello intercorrente tra il 1 gennaio 1993 e la data di decorrenza della pensione; previsione di adeguati correttivi a favore dei lavoratori collocati in mobilita';
- i) facolta' per i lavoratori dipendenti, che possono far valere complessivamente almeno cinque anni di contribuzione versata in costanza di effettiva attivita' lavorativa, di riscattare, a domanda, con le norme e le modalita' di cui all'articolo 13 della legge 12 agosto 1962, n. 1338, e nella misura massima complessiva di cinque anni, successivi al 1 gennaio 1994, periodi corrispondenti a quelli di assenza facoltativa del lavoro per gravidanza e puerperio, periodi di congedo per motivi familiari concernenti l'assistenza e cura di disabili in misura non inferiore all'80 per cento, purche' in ogni caso si tratti di periodi non coperti da assicurazione, con esclusione delle cumulabilita' con il riscatto del periodo di corso legale di laurea, ad eccezione dei periodi obbligatori relativi a gravidanze e puerperio che saranno coperti da contribuzione figurativa anche se intervenuti al di fuori del rapporto di lavoro;
- l) determinazione di un limite massimo non superiore a cinque anni per i periodi figurativi computabili ai fini del diritto a pensione di anzianita' limitatamente ai lavoratori di nuova assunzione privi di anzianita' assicurativa;
- m) armonizzazione ed estensione della disciplina in materia di limitazioni al cumulo delle pensioni con i redditi da lavoro subordinato ed autonomo per tutti i lavoratori pubblici e privati, con esclusione della non cumulabilita' per i redditi derivanti da attivita' promosse da enti locali e altre istituzioni pubbliche e privati per programmi di reinserimento degli anziani in attivita' socialmente utili o da attivita' sia autonome sia dipendenti di limitata rilevanza economica o che comportino un limitato impegno temporale; i lavoratori che, al 31 dicembre 1992, risultano gia' pensionati, continuano a percepire, se piu' favorevoli, i trattamenti in atto;
- n) elevazione, a decorrere dal 1 gennaio 1994, di un anno del requisito contributivo richiesto per il pensionamento di anzianita' di tutti i regimi, ad eccezione di coloro che a tale data abbiano compiuto l'eta' di cinquantasette anni per gli uomini e di cinquantadue anni per le donne, e graduale estensione della disciplina del regime generale obbligatorio in materia di pensione di anzianita' a tutti i lavoratori dipendenti privati e pubblici, prevedendo: 1) la conservazione del diritto al pensionamento, per coloro che hanno maturato l'anzianita' contributiva e di servizio prevista nei singoli ordinamenti per poter usufruire di tale diritto; 2) il differimento della possibilita' di pensionamento a non prima del compimento del trentacinquesimo anno di anzianita' contributiva e di servizio per coloro che hanno maturato un'anzianita' contributiva e di servizio non superiore ad otto anni; 3) una maggiorazione per tutti gli altri lavoratori degli anni di servizio inversamente proporzionale all'anzianita' contributiva e di servizio mancante al raggiungimento dei requisiti previsti nei singoli ordinamenti, in modo da raggiungere la piena parificazione in un periodo massimo di dieci anni; 4) la concessione della pensione di anzianita' dopo l'effettiva cessazione dell'attivita' lavorativa, dipendente o autonoma, con identici criteri di non cumulabilita' tra pensione e retribuzione o reddito da lavoro autonomo;
- o) estensione della disciplina dell'assicurazione generale obbligatoria per l'invalidita', la vecchia ed i superstiti dei lavoratori dipendenti, limitatamente ai lavoratori di nuova assunzione privi di anzianita' assicurativa, con riferimento del calcolo della pensione alla contribuzione dell'intera vita lavorativa, adeguata secondo i criteri di cui alla lettera h), alle forme pensionistiche esclusive e sostitutive del regime generale, nei limiti compatibili con le specifiche peculiarita' e le particolari caratteristiche del rapporto di lavoro delle singole categorie; estensione del riferimento dell'intera vita contributiva ai lavoratori autonomi limitatamente alle attivita' iniziate successivamente al 31 dicembre 1992, che diano luogo a nuova iscrizione alla rispettiva gestione, secondo criteri e correttivi equipollenti a quelli previsti per i lavoratori dipendenti;
- p) previsione che i principi e i criteri direttivi di cui alle lettere g), h), m), n), q), t), u) e v) si applichino al personale di cui all'articolo 2 del decreto legislativo 20 novembre 1990, n. 357. Le conseguenti variazioni del trattamento previdenziale erogato dalla gestione speciale istituita ai sensi dell'articolo 1, comma 2, del citato decreto legislativo n. 357 del 1990 non determinano oneri aggiuntivi a carico dei fondi o casse o a carico dei datori di lavoro di cui, rispettivamente, all'articolo 5 del citato decreto legislativo n. 357 del 1990 e all'articolo 1 della legge 30 luglio 1990, n. 218, salvo che venga diversamente stabilito in sede di contrattazione;
- q) disciplina della perequazione automatica delle pensioni dei lavoratori dipendenti ed autonomi al fine di garantire, tenendo anche conto del sistema relativo ai lavoratori in attivita', la salvaguardia del loro potere di acquisto;
- r) conservazione per le forme pensionistiche di cui alla lettera o) dell'autonomia di gestione e, se piu' favorevole, della normativa vigente in materia di invalidita' specifiche e per causa di servizio;
- s) revisione ed armonizzazione dei requisiti reddituali per le integrazioni al trattamento minimo e per le maggiorazioni sociali delle pensioni, al fine di assicurare al nucleo familiare del pensionato, computandovi il reddito del coniuge, un reddito spendibile non inferiore al livello minimo vitale;
- t) ristrutturazione ed armonizzazione della disciplina di finanziamento del sistema previdenziale, stabilendo per ciascuna gestione previdenziale aliquote contributive idonee ad assicurare l'equilibrio gestionale, con esclusione di imposizione contributiva sul corrispettivo dei servizi messi a disposizione dei lavoratori da parte dei datori di lavoro;
- u) disciplina transitoria per il calcolo delle pensioni da determinare in quota parte in base alla previgente normativa a garanzia dei diritti maturati;
- v) previsione di piu' elevati livelli di copertura previdenziali, disciplinando la costituzione, la gestione e la vigilanza di forme di previdenza anche articolate secondo criteri di flessibilita' e diversificazione per categorie di beneficiari, per la erogazione di trattamenti pensionistici complementari del sistema obbligatorio pubblico per i lavoratori dipendenti, i lavoratori autonomi ed i liberi professionisti, su base volontaria, collettiva o individuale, con garanzia di autonomia e separazione contabile e patrimoniale, mediante gestioni dirette o convenzionate affidate, in regime di concorrenza, agli organismi gestori delle forme di obbligatorie di previdenza e assistenza ivi compresi quelli cui si applica l'articolo 1 della legge 9 marzo 1989, n. 88, nonche' alle imprese assicurative abilitate alla gestione del ramo VI, di cui alla tabella allegata alla legge 22 ottobre 1986, n. 742, alle societa' di intermediazione mobiliare (SIM) e ad operatori pubblici e privati, con l'osservanza di sistemi di capitalizzazione, con la partecipazione negli organi di amministrazione e di controllo interno di rappresentanti dei soggetti che concorrono al finanziamento delle gestioni, prevedendosi la possibilita' di concessione di agevolazioni fiscali in coerenza con gli obiettivi stabiliti dall'articolo 17 della legge 29 dicembre 1990, n. 408;
- z) revisione delle aliquote di rendimento indicate nella tabella di cui all'articolo 21, comma 6, della legge 11 marzo 1988, n. 67, secondo criteri di gradualita' ed equita', con armonizzazione dei rendimenti delle forme di previdenza sostitutive ed esclusive dell'assicurazione generale obbligatoria, tenendo conto delle specificita' delle posizioni e dei rapporti di lavoro e di meccanismi di solidarieta';
- aa) razionalizzazione dei sistemi di accertamento dei lavoratori dell'agricoltura e di accertamento e riscossione dei contributi, tenuto conto della disciplina vigente per la generalita' dei lavoratori e dei principi contenuti nella legge 9 marzo 1989, n. 88, al fine di una migliore efficienza del servizio e del rafforzamento delle misure contro le evasioni e le elusioni; revisione e semplificazione delle norme concernenti le agevolazioni contributive.

2. Entro sessanta giorni dalla data di entrata in vigore della presente legge il Governo trasmette alla Camera dei deputati e al Senato della Repubblica gli schemi dei decreti legislativi di cui al comma 1, ad eccezione di quelli in attuazione dei principi e dei criteri direttivi di cui alle lettere f), o), v) e aa) del medesimo comma 1, al fine dell'espressione del parere da parte delle Commissioni permanenti competenti per la materia di cui al presente articolo. Il termine per l'emanazione dei decreti legislativi in attuazione dei principi e dei criteri direttivi di cui alle lettere f), o), v) e aa) del comma 1 e' stabilito in duecentosettanta giorni ed i relativi schemi debbono essere trasmessi alla Camera dei deputati ed al Senato della Repubblica almeno trenta giorni prima della scadenza. Le Commissioni si esprimono entro quindici giorni dalla data di trasmissione. ;

3. Disposizioni correttive, nell'ambito dei decreti di cui al comma 1, nel rispetto dei principi e criteri direttivi determinati dal medesimo comma 1 e previo parere delle Commissioni di cui al comma 2, potranno essere emanate, con uno o piu' decreti legislativi, fino al 31 dicembre 1993.

## Art. 4. - (Finanza degli enti territoriali).

1. Al fine di consentire alle regioni, alle province ed ai comuni di provvedere ad una rilevante parte del loro fabbisogno finanziario attraverso risorse proprie, il Governo della Repubblica e' delegato ad emanare, entro novanta giorni dalla data di entrata in vigore della presente legge, salvo quanto previsto al comma 7 del presente articolo, uno o piu' decreti legislativi, diretti:

- a) all'istituzione, a decorrere dall'anno 1993, dell'imposta comunale immobiliare (ICI), con l'osservanza dei seguenti principi e criteri direttivi: 1) applicazione dell'ICI sul valore dei fabbricati, dei terreni agricoli e delle aree fabbricabili a qualsiasi uso destinati e attribuzione della titolarita' dell'imposta al comune ove sono ubicati gli immobili; 2) assoggettamento all'imposta, per anni solari, del proprietario dell'immobile ovvero del titolare del diritto di usufrutto, uso o abitazione sullo stesso, anche se non residente nel territorio dello Stato; l'imposta e' dovuta proporzionalmente al periodo ed alla quota di possesso nel corso dell'anno; 3) determinazione del valore dei fabbricati sulla base degli estimi del catasto edilizio o valore comparativo in caso di non avvenuta iscrizione al catasto; negli anni successivi le rendite catastali, su cui sono calcolati i valori degli immobili, sono rivalutate periodicamente in base a parametri che tengano in considerazione gli effettivi andamenti dei mercati immobiliari; 4) determinazione del valore dei terreni agricoli sulla base degli estimi del catasto; 5) determinazione del valore delle aree fabbricabili sulla base del valore venale in comune commercio, esclusi i terreni su cui persista l'utilizzazione agro-silvo-pastorale da parte dei soggetti indicati al numero 10), demandando al comune, se richiesto, con propria certificazione, la definizione di area fabbricabile; negli eventuali procedimenti di espropriazione si assume il valore dichiarato ai fini dell'ICI se inferiore all'indennita' di espropriazione determinata secondo i vigenti criteri. In caso di utilizzazione edificatoria dell'area, di demolizione di fabbricato, di interventi di recupero a norma dell'articolo 31, primo comma, lettere c), d) ed e), della legge 5 agosto 1978, n. 457, la base imponibile e' costituita dal valore dell'area fino alla data di ultimazione dei lavori di costruzione, ricostruzione o ristrutturazione o, comunque, fino alla data in cui il fabbricato e' assoggettato all'ICI; 6) determinazione di un'aliquota unica da parte del comune in misura variante dal 4 al 6 per mille, con applicazione della aliquota minima in caso di mancata determinazione e con facolta' di aumentare l'aliquota massima fino all'uno per mille per straordinarie esigenze di bilancio; 7) esenzione dall'imposta per: 7.1) lo Stato, le regioni, le province, i comuni, le comunita' montane, i consorzi fra detti enti, le unita' sanitarie locali, le istituzioni sanitarie pubbliche autonome di cui all'articolo 41 della legge 23 dicembre 1978, n. 833, nonche' le camere di commercio, industria, artigianato ed agricoltura. L'esenzione spetta limitatamente agli immobili destinati esclusivamente ai compiti istituzionali dell'ente; 7.2) gli immobili utilizzati dai soggetti di cui all'articolo 87, comma 1, lettera c), del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, destinati esclusivamente allo svolgimento di attivita' assistenziali, previdenziali, sanitarie, didattiche, ricettive, culturali, ricreative e sportive, nonche' delle attivita' di cui all'articolo 16, lettera a), della legge 20 maggio 1985, n. 222; 7.3) i fabbricati destinati esclusivamente all'esercizio del culto, purche' compatibile con le disposizioni degli articoli 8 e 19 della Costituzione, e le loro pertinenze; 7.4) i fabbricati di proprieta' della Santa Sede indicati negli articoli 13, 14, 15 e 16 del Trattato lateranense, sottoscritto l'11 febbraio 1929 e reso esecutivo con legge 27 maggio 1929, n. 810; 7.5) i fabbricati appartenenti agli Stati esteri per i quali e' prevista l'esenzione dall'imposta locale sul reddito dei fabbricati in base ad accordi internazionali resi esecutivi in Italia; 7.6) i fabbricati con destinazione ad usi culturali di cui all'articolo 5-bis del decreto del Presidente della Repubblica 29 settembre 1973, n. 601, e successive modificazioni; 7.7) i fabbricati classificati o classificabili nelle categorie catastali da E/1 ad E/9; 7.8) i fabbricati in corso d'opera non utilizzati; 7.9) i fabbricati di cui al n. 8) recuperati al fine di essere destinati alle attivita' assistenziali di cui alla legge 5 febbraio 1992, n. 104, per il periodo in cui sono adibiti direttamente allo svolgimento delle attivita' predette; 7.10) i terreni agricoli ricadenti in aree montane o di collina delimitate ai sensi dell'articolo 15 della legge 27 dicembre 1977, n.984; 8) riduzione dell'imposta del 50 per cento per i fabbricati dichiarati inagibili o inabitabili e di fatto non utilizzati; 9) detrazione dall'imposta dovuta per l'unita' immobiliare adibita ad abitazione principale del soggetto passivo di un importo di lire 180.000 rapportato al periodo e alla quota per i quali sussiste la detta destinazione. La disposizione si applica anche per le unita' immobiliari adibite ad abitazione principale dei soci assegnatari di cooperative edilizie a proprieta' indivisa; 10) i terreni agricoli di proprieta' di coltivatori diretti o imprenditori agricoli che esplicano la loro attivita' a titolo principale, purche' dai medesimi condotti, il cui valore sia non superiore a lire 50 milioni complessive, sono esenti da imposta. Sui medesimi terreni agricoli l'imposta e' dovuta per scaglioni di valore imponibile complessivo, nelle seguenti misure: 10.1) nella misura del 30 per cento per un valore complessivo compreso tra 50 milioni e 120 milioni; 10.2) nella misura del 50 per cento per un valore compreso tra 120 milioni e 200 milioni; 10.3) nella misura del 75 per cento per un valore compreso tra 200 milioni e 250 milioni; 11) accertamento e riscossione dell'imposta a cura del comune, previa dichiarazione da parte del soggetto passivo, da trasmettere anche all'anagrafe tributaria; attribuzione da parte della giunta comunale della responsabilita' di gestione dell'imposta ad un funzionario; collaborazione informativa tra il Ministero delle finanze ed i comuni anche a mezzo del sistema telematico dei comuni; 12) rimborso dell'imposta pagata, con relativi interessi nella misura legale, per le aree divenute inedificabili, a condizione che il vincolo di inedificabilita' perduri per almeno tre anni; il rimborso e' limitato all'imposta pagata per il periodo di tempo decorrente dall'ultimo acquisto per atto tra vivi dell'area e, comunque, per un periodo non eccedente i dieci anni; 13) devoluzione delle controversie alla competenza delle commissioni tributarie; 14) determinazione di soprattasse in misura non eccedente il 50 per cento dell'imposta o della maggiore imposta dovuta ed il 20 per cento dell'imposta non versata o tardivamente versata, graduandone l'entita' in relazione alla gravita' dell'infrazione e prevedendo la inapplicabilita' della soprattassa per omesso o tardivo versamento dipendente da procedure fallimentari in corso; 15) determinazione di pene pecuniarie in misura non eccedente lire 200.000 per le infrazioni di carattere formale; 16) esclusione dei redditi dominicali delle aree fabbricabili, dei redditi dei terreni agricoli e dei redditi dei fabbricati dall'ambito di applicazione dell'imposta locale sui redditi (ILOR), nonche' detrazione, per l'abitazione principale, dall'imposta sul reddito delle persone fisiche (IRPEF) di un importo non eccedente 120.000 lire e di uguale importo dall'imposta sul reddito delle persone giuridiche (IRPEG) per ognuna delle unita' immobiliari delle cooper- ative edilizie a proprieta' indivisa adibita ad abitazione principale dei soci assegnatari; 17) soppressione dal 1 gennaio 1993, dell'imposta comunale sull'incremento di valore degli immobili (INVIM); tuttavia ne sara' prevista l'applicazione, con le aliquote massime e l'acquisizione del gettito all'erario dello Stato per i presupposti di imposta che si verificano nel decennio successivo al 31 dicembre 1992, assumendo come valore finale quello al 31 dicembre 1992; 18) in caso di espropriazione per pubblica utilita', oltre alla indennita' determinata secondo i criteri vigenti, e' dovuta una eventuale maggiorazione pari alla differenza tra l'importo dell'ICI corrisposta dall'espropriato, o dal suo dante causa, negli ultimi cinque anni e l'importo dell'ICI che sarebbe stato corrisposto sulla base dell'indennita', oltre gli interessi legali sulla stessa differenza; 19) non deducibilita' dell'ICI agli effetti delle imposte erariali sui redditi;
- b) all'attribuzione ai comuni, a decorrere dal 1994, della facolta', connessa alla politica degli investimenti, di istituire una addizionale all'IRPEF in misura non eccedente l'uno per cento dell'imposta relativa all'anno 1993, il 2 per cento di quella relativa all'anno 1994, il 3 per cento di quella relativa all'anno 1995 ed il 4 per cento di quella relativa agli anni 1996 e successivi. Con delibera del consiglio comunale possono essere stabilite riduzioni dell'addizionale per categorie di meno abbienti individuate sulla base di indici obiettivi di carattere sociale. L'addizionale e' riscossa, mediante distinto versamento, in unica soluzione, nei termini e secondo le modalita' previsti per il versamento a saldo dell'IRPEF. Il provento dell'addizionale e' devoluto dallo Stato in favore del comune di domicilio fiscale del contribuente. Per la disciplina dell'addizionale si applicano le disposizioni in materia di IRPEF; l'addizionale non e' deducibile agli effetti delle imposte erariali sul reddito. Saranno, altresi', emanate norme dirette ad ampliare ed incentivare, anche prevedendo forme di compartecipazione al maggior gettito risultante dalla stessa attivita', l'attivita' di segnalazione dei comuni prevista dal terzo comma dell'articolo 44 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e successive modificazioni;
- c) all'attribuzione, a decorrere dal 1 gennaio 1993, alle regioni a statuto ordinario - gia' titolari di una parte della tassa automobilistica, ai sensi dell'articolo 4 della legge 16 maggio 1970, n. 281, come sostituito dall'articolo 5 della legge 14 giugno 1990, n. 158, e successive modificazioni - dell'intera tassa automobilistica complessivamente dovuta, nonche' della soprattassa annuale di cui all'articolo 8 del decreto-legge 8 ottobre 1976, n. 691, convertito, con modificazioni, dalla legge 30 novembre 1976, n. 786, e della tassa speciale di cui all'articolo 2 della legge 21 luglio 1984, n. 362, con l'osservanza dei seguenti principi e criteri direttivi: 1) le misure della tassa automobilistica, della soprattassa annuale e della tassa speciale possono essere stabilite, con effetto dal 1 gennaio di ciascun anno, alle scadenze previste nell'articolo 4 della legge 16 maggio 1970, n. 281, nel testo modificato dalla legge 14 giugno 1990, n. 158, e successive modificazioni, nella misura compresa fra il 90 ed il 110 per cento di quelle vigenti nell'anno precedente; 2) la tassa automobilistica, la soprattassa annuale e la tassa speciale sono disciplinate dalle stesse norme che regolano gli analoghi tributi erariali vigenti nel territorio delle regioni a statuto speciale, ivi comprese quelle concernenti le sanzioni e la loro entita', e sono riscosse negli stessi termini, con le stesse modalita' ed a mezzo dello stesso concessionario della riscossione degli analoghi tributi erariali, il quale versera' i tributi regionali riscossi nelle casse della regione di competenza ed avra' diritto allo stesso aggio fissato per i detti tributi erariali; 3) la rinnovazione dell'immatricolazione di un veicolo o di un autoscafo in una provincia compresa nel territorio di una regione diversa da quella nel cui ambito era precedentemente iscritto non da' luogo all'applicazione di una ulteriore tassa, soprattassa annuale e tassa speciale per il periodo per il quale il tributo dovuto e' stato riscosso dalla regione di provenienza; 4) contestuale riduzione del fondo comune di cui all'articolo 8 della legge 16 maggio 1970, n. 281;
- d) all'istituzione, a decorrere dal 1994, a favore delle regioni a statuto ordinario di un'imposta sull'erogazione del gas e dell'energia elettrica per usi domestici commisurata al prezzo, al netto di imposte e tasse, delle erogazioni e di una analoga imposta a favore delle province, secondo i seguenti principi e criteri direttivi: 1) l'imposta puo' essere proporzionale o progressiva a scaglioni in rapporto al crescere dei consumi; 2) l'imposta regionale e' determinata da ciascuna regione, con propria legge, in misura complessivamente non eccedente il 6 per cento; 3) l'imposta provinciale e' deliberata da ciascuna provincia in misura complessivamente non eccedente l'uno per cento; 4) l'imposta regionale e l'imposta provinciale sono dovute alla regione ed alla provincia ove sono ubicate le utenze dai soggetti erogatori con obbligo di rivalsa sugli utenti; 5) in armonia con le disposizioni di carattere generale in materia di tributi regionali e provinciali saranno determinati le modalita' di articolazione delle aliquote, fra il minimo e il massimo, le modalita' di accertamento, i termini per il versamento alle regioni ed alle province dei relativi tributi, nonche' le sanzioni, le indennita' di mora e gli interessi per il mancato o ritardato versamento;
- e) all'istituzione, a decorrere dal 1993, a favore delle province, di una o piu' imposte sull'esercizio delle funzioni di cui alle lettere a), b), d) e g) del comma 1 dell'articolo 14 della legge 8 giugno 1990, n. 142;
- f) all'applicazione agli enti locali di una disciplina dei trasferimenti correnti che, nell'ambito dell'articolo 54 della legge 8 giugno 1990, n. 142, tenga conto dei seguenti principi e criteri direttivi: 1) istituzione di un sistema a regime di determinazione del complesso dei trasferimenti erariali agli enti locali che, salve le detrazioni di cui al numero 2), garantisca dal 1994 un andamento coordinato con i principi di finanza pubblica e con la crescita della spesa statale contenuti nei documenti di programmazione statale, con unificazione degli stanziamenti di bilancio di carattere ripetitivo, secondo le tipologie previste dall'articolo 54 della legge 8 giugno 1990, n. 142, e con definizione delle rispettive quantificazioni; 2) corresponsione ai comuni per il 1993 di trasferimenti ordinari e perequativi pari a quelli corrisposti nel 1992, al lordo della detrazione di cui al decreto-legge 11 luglio 1992, n. 333, convertito, con modificazioni, dalla legge 8 agosto 1992, n. 359, eventualmente aumentati secondo le indicazioni della legge finanziaria per lo stesso anno e versamento all'erario da parte dei comuni del gettito dell'ICI calcolato con l'aliquota del 4 per mille, al netto della perdita del gettito INVIM calcolato sulla base della media delle riscossioni del triennio 1990-1992; corresponsione alle province di trasferimenti ordinari e perequativi calcolati in modo analogo a quello dei comuni; corresponsione alle comunita' montane per il 1993 di fondi ordinari pari a quelli del 1992 ed aumentati con lo stesso metodo adottato per i comuni; detrazione dai trasferimenti erariali correnti, a decorrere dal 1994, di un importo complessivo pari al gettito dovuto per l'anno 1993 dell'ICI calcolato sulla base dell'aliquota del 4 per mille, ridotto della perdita derivante dalla soppressione dell'INVIM; gli accertamenti dell'ICI dovuta per l'anno 1993, in deroga a quanto disposto nella lettera a), numeri 11), 14) e 15), sono effettuati dall'Amministrazione finanziaria in base alle disposizioni vigenti in materia di imposte sui redditi, avvalendosi anche dei dati ed elementi forniti dai comuni; le somme riscosse dall'Amministrazione finanziaria per effetto di detti accertamenti sono di spettanza dello Stato, sino alla concorrenza dell'aliquota obbligatoria; 3) conservazione a ciascun ente locale di contributi erariali che finanzino i servizi indispensabili di cui all'articolo 54 della legge 8 giugno 1990, n. 142, per le materie di competenza statale, delegate o attribuite all'ente locale stesso; 4) applicazione dal 1994 dei parametri obiettivi stabiliti dal predetto articolo 54 della legge n. 142 del 1990 e attuazione dello stesso anno della perequazione degli squilibri della fiscalita' lo- cale, con particolare considerazione: 4.1) dei comuni montani con popolazione inferiore a 5.000 abitanti; 4.2) dei comuni non montani con popolazione inferiore a 2.000 abitanti; 4.3) dei comuni operanti in zone particolarmente depresse con ridotte basi imponibili immobiliari e di reddito; 4.4) dei comuni capoluogo di provincia; 4.5) degli enti aventi nel 1992 trasferimenti erariali ordinari e perequativi, per abitante, inferiori a quelli della fascia demografica di appartenenza; 5) ripartizione del fondo per trasferimenti correnti alle comunita' montane, con quote di fabbisogno minimo per ente e con riferimento alla popolazione montana; 6) eliminazione, successivamente al periodo transitorio, dei vincoli in atto esistenti sul controllo centrale delle piante organiche, sulle assunzioni di personale e sui tassi di copertura del costo dei servizi, tranne che per gli enti locali con situazioni strutturalmente deficitarie; 7) certificazione amministrativa dei bilanci di previsione e dei conti consuntivi degli enti locali e dei relativi consorzi, con previsione di ritardo nell'erogazione dei trasferimenti erariali per i trasgressori;
- g) all'autorizzazione alle province, ai comuni, ai loro consorzi, alle aziende municipalizzate ed alle comunita' montane ad assumere mutui per il finanziamento di opere pubbliche destinate all'esercizio di servizi pubblici, assistiti o meno da contributi in conto capitale o in conto interessi dello Stato o delle regioni soltanto sulla base di progetti "chiavi in mano" ed a prezzo chiuso. Il piano finanziario previsto dall'articolo 4, comma 9, del decreto-legge 2 marzo 1989, n. 65, convertito, con modificazioni, dalla legge 26 aprile 1989, n. 155, deve assicurare l'equilibrio economico-finanziario dell'investimento e della connessa gestione, anche in relazione agli introiti previsti e deve essere preventivamente assentito da un istituto di credito mobiliare scelto nell'elenco che sara' approvato dal Ministro del tesoro. Le opere di cui alla presente lettera che superano l'importo di un miliardo di lire dovranno essere sottoposte a monitoraggio economico e gestionale, a cura di societa' specializzata all'uopo autorizzata dal Ministro dell'interno di concerto con il Ministro del tesoro, con riparto dei costi relativi tra l'ente mutuatario e l'istituto di credito mobiliare finanziatore. Per gli interventi di cui alla presente lettera gli enti interessati approvano le tariffe dei servizi pubblici in misura tale da assicurare l'equilibrio economico-finanziario dell'investimento e della connessa gestione.

2. Il Governo della Repubblica e' delegato ad emanare, entro dodici mesi dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi diretti al riordino dell'ordinamento finanziario e contabile delle amministrazioni provinciali, dei comuni, dei loro consorzi e delle comunita' montane, con l'osservanza dei seguenti principi e criteri direttivi:

- a) armonizzazione con i principi della contabilita' generale dello Stato, per la parte applicativa dei principi contenuti nella legge 8 giugno 1990, n. 142, tenuto conto delle esigenze del consolidamento dei conti pubblici e dell'informatizzazione;
- b) applicazione dei principi contenuti nella legge 8 giugno 1990, n. 142, con l'introduzione in forma graduale e progressiva della contabilita' economica a decorrere dal 1995 fino ad interessare tutti gli enti, con facolta' di applicazione anticipata;
- c) definizione, nell'ambito del sistema di contabilita' economica, dei principi per la determinazione dei costi e degli ammortamenti dei servizi degli enti locali;
- d) inclusione nell'ordinamento finanziario e contabile della possibilita' di ricorso all'istituto del dissesto per il risanamento degli enti locali in grave crisi finanziaria, secondo i criteri contenuti nelle leggi in vigore, e coordinamento delle norme in materia.

3. Restano salve le competenze e le attribuzioni delle regioni a statuto speciale e delle province autonome di Trento e di Bolzano.

4. Il Governo della Repubblica e', altresi', delegato ad emanare, entro dodici mesi dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi diretti alla revisione ed armonizzazione, con effetto dal 1 gennaio 1994, di tributi locali vigenti, secondo i seguenti principi e criteri direttivi:

- a) in materia di imposta comunale sulla pubblicita' e diritti sulle pubbliche affisioni: 1) tassazione della pubblicita' esterna avente finalita' commerciale o rilevanza economica, assumendo come paramentro di commisurazione dell'imposta il mezzo pubblicitario utilizzato, secondo la sua natura, le sue dimensioni e la sua ubicazione; 2) attribuzione della soggettivita' passiva a colui che dispone dei mezzi pubblicitari e regolamentazione della responsabilita' tributaria di colui che produce, vende la merce o fornisce i servizi oggetto della pubblicita'; 3) ridefinizione delle tariffe sulla base delle disposizioni di cui al numero 1), ripartendo i comuni in non piu' di cinque classi, in modo che la previsione di gettito per l'anno 1994 non ecceda il doppio del gettito lordo registrato nel 1992. Per le pubbliche affisioni le tariffe saranno stabilite tenendo conto del costo medio del servizio reso; 4) revisione delle disposizioni riguardanti la gestione dell'imposta sulla pubblicita' nonche' del servizio delle pubbliche affissioni, sulla base anche dell'articolo 22 della legge 8 giugno 1990, n. 142;
- b) in materia di tasse per l'occupazione di spazi ed aree pubbliche di pertinenza dei comuni e delle province: 1) rideterminazione delle tariffe al fine di una piu' adeguata rispondenza al beneficio economico ritraibile nonche' in relazione alla ripartizione dei comuni in non piu' di cinque classi. Le variazioni in aumento, per le occupazioni permanenti, non potranno superare il 50 per cento delle misure massime di tassazione vigente; le tariffe per le occupazioni temporanee, per ciascun giorno, non potranno superare il 10 per cento di quelle stabilite, per ciascun anno, ai fini delle occupazioni permanenti ordinarie di cui all'articolo 195 del testo unico per la finanza locale approvato con regio decreto 14 settembre 1931, n. 1175, e successive modificazioni, e potranno essere graduate in relazione al tempo di occupazione; 2) introduzione di forme di determinazione forfettaria della tassa per le occupazioni di spazi soprastanti e sottostanti il suolo con linee elettriche, cavi, condutture e simili, tenendo conto di parametri significativi; 3) soppressione della tassa per le occupazioni permanenti di aree pubbliche con balconi, verande e simili di carattere stabile, gravante sulle unita' immobiliari, e determinazione di criteri certi per la tassa sui passi carrabili; 4) regolamentazione della gestione della tassa secondo criteri analoghi a quelli previsti per l'imposta comunale sulla pubblicita' e diritti sulle pubbliche affissioni;(2)
- c) in materia di tassa per lo smaltimento dei rifiuti solidi urbani: 1) adeguamento del tributo alla sua natura di tassa anche mediante un piu' diretto collegamento tra fruibilita' del servizio e applicabilita' della tassa nonche' attraverso la determinazione di parametri di commisurazione del prelievo sulla base della potenzialita' di produzione di rifiuti definita mediante adeguati criteri oggettivi; 2) definizione di precise modalita' di equiparazione ai rifiuti urbani, ai fini del regime di privativa comunale e di applicazione della tassa, dei residui derivanti dalle attivita' produttive;
- d) in materia di imposta comunale sulla pubblicita' e di diritti sulle pubbliche affissioni, di tassa di occupazione e di tassa per lo smaltimento dei rifiuti solidi urbani: 1) revisione ed armonizzazione del procedimento di accertamento e riscossione, con la previsione anche di versamenti diretti a mezzo conto corrente postale, con applicazione, per la riscossione coattiva, delle disposizioni del decreto del Presidente della Repubblica 28 gennaio 1988, n. 43; 2) revisione delle agevolazioni, mantenendo solo quelle che rispondono a finalita' di carattere sociale e di economicita' di gestione;
- e) in materia di imposte e tasse comunali e provinciali, attribuzione alla Direzione generale per la finanza locale presso il Ministero delle finanze della funzione di vigilanza sulle gestioni dei servizi tributari, anche mediante controlli sulle delibere adottate per regolamenti e tariffe, al fine di verificare l'osservanza delle disposizioni che disciplinano i singoli tributi e il regolare funzionamento dei servizi.

5. All'onere derivante dall'applicazione del comma 1, valutato in lire 29.423 miliardi per l'anno 1993 e lire 24.010 miliardi per l'anno 1994, si provvede:

- a) quanto a lire 1.650 miliardi per l'anno 1993 e lire 1.700 miliardi per l'anno 1994, mediante utilizzo delle entrate indicate all'articolo 4 del decreto-legge 30 settembre 1989, n. 332, convertito, con modificazioni, dalla legge 27 novembre 1989, n. 384, come da ultimo modificato dall'articolo 6 del decreto-legge 13 maggio 1991, n. 151, convertito, con modificazioni, dalla legge 12 luglio 1991, n. 202;
- b) quanto a lire 8.790 miliardi per l'anno 1993, con le maggiori entrate di cui al comma 1, lettera f), numero 2);
- c) quanto a lire 15.433 miliardi per l'anno 1993 e lire 18.900 miliardi per l'anno 1994, mediante parziale utilizzo delle proiezioni per gli stessi anni dell'accantonamento "Disposizioni finanziarie per le province, per i comuni e le comunita' montane" iscritto, ai fini del bilancio triennale 1992-1994, al capitolo 6856 dello stato di previsione del Ministero del tesoro per l'anno 1992;
- d) quanto a lire 3.550 miliardi per l'anno 1993 e lire 3.410 miliardi per l'anno 1994, mediante parziale utilizzo delle proiezioni dello stanziamento iscritto al capitolo 5926 dello stato di previsione del Ministero del tesoro per l'anno 1992 e corrispondenti capitoli per gli anni successivi, all'uopo intendendosi corrispondentemente ridotta l'autorizzazione di spesa di cui all'articolo 8 della legge 16 maggio 1970, n. 281. 6.Il Ministro del tesoro e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio. 7. Al fine dell'espressione del parere da parte delle Commissioni permanenti competenti per la materia di cui al presente articolo, il Governo trasmette alla Camera dei deputati e al Senato della Repubblica gli schemi dei decreti legislativi in attuazione dei principi e dei criteri direttivi di cui al comma 1, lettere a), c), e), f) e g), entro sessanta giorni dalla data di entrata in vigore della presente legge, e gli schemi dei decreti legislativi in attuazione dei principi e dei criteri direttivi di cui al comma 1, lettere b) e d); e ai commi 2 e 4, entro dieci mesi dalla predetta data. Le Commissioni si esprimono entro quindici giorni dalla data di trasmissione. I decreti legislativi in attuazione dei principi e dei criteri direttivi di cui al comma 1, lettere b) e d), sono emanati entro dodici mesi dalla data di entrata in vigore della presente legge. 8. Disposizioni correttive, nell'ambito dei decreti di cui al presente articolo, nel rispetto dei principi e criteri direttivi determinati dall'articolo stesso e previo parere delle Commissioni di cui al comma 7, potranno essere emanate, con uno o piu' decreti legislativi, fino al 31 dicembre 1993.((3))

